summaryrefslogtreecommitdiffstats
path: root/tqtinterface/qt4/src/3rdparty/libmng
diff options
context:
space:
mode:
authorTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-08-10 12:13:27 -0500
committerTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-08-10 12:13:27 -0500
commitd296f1d337dabfeae5191955fdadb874965dbbe9 (patch)
tree1a4b3b4cca01f2ea77eee2497297219d60e9bbd4 /tqtinterface/qt4/src/3rdparty/libmng
parenteaa7ee2e0bbca40ba3173c4304f81957e8964291 (diff)
downloadexperimental-d296f1d337dabfeae5191955fdadb874965dbbe9.tar.gz
experimental-d296f1d337dabfeae5191955fdadb874965dbbe9.zip
rename the following methods:
tqparent parent tqmask mask
Diffstat (limited to 'tqtinterface/qt4/src/3rdparty/libmng')
-rwxr-xr-xtqtinterface/qt4/src/3rdparty/libmng/config.guess2
-rwxr-xr-xtqtinterface/qt4/src/3rdparty/libmng/configure2
-rw-r--r--tqtinterface/qt4/src/3rdparty/libmng/doc/libmng.txt10
-rw-r--r--tqtinterface/qt4/src/3rdparty/libmng/doc/man/libmng.310
-rw-r--r--tqtinterface/qt4/src/3rdparty/libmng/libmng.h2
-rw-r--r--tqtinterface/qt4/src/3rdparty/libmng/libmng_display.c2
-rw-r--r--tqtinterface/qt4/src/3rdparty/libmng/libmng_pixels.c142
-rw-r--r--tqtinterface/qt4/src/3rdparty/libmng/libmng_trace.h2
8 files changed, 86 insertions, 86 deletions
diff --git a/tqtinterface/qt4/src/3rdparty/libmng/config.guess b/tqtinterface/qt4/src/3rdparty/libmng/config.guess
index 6372bf0..dff9e48 100755
--- a/tqtinterface/qt4/src/3rdparty/libmng/config.guess
+++ b/tqtinterface/qt4/src/3rdparty/libmng/config.guess
@@ -195,7 +195,7 @@ main:
.prologue 1
.long 0x47e03d80 # implver \$0
lda \$2,-1
- .long 0x47e20c21 # atqmask \$2,\$1
+ .long 0x47e20c21 # amask \$2,\$1
lda \$16,\$Lformat
mov \$0,\$17
not \$1,\$18
diff --git a/tqtinterface/qt4/src/3rdparty/libmng/configure b/tqtinterface/qt4/src/3rdparty/libmng/configure
index 9a796af..fb7d7be 100755
--- a/tqtinterface/qt4/src/3rdparty/libmng/configure
+++ b/tqtinterface/qt4/src/3rdparty/libmng/configure
@@ -647,7 +647,7 @@ ac_unique_file=libmng.h
# Find the source files, if location was not specified.
if test -z "$srcdir"; then
ac_srcdir_defaulted=yes
- # Try the directory containing this script, then its tqparent.
+ # Try the directory containing this script, then its parent.
ac_prog=$0
ac_confdir=`echo $ac_prog|sed 's%/[^/][^/]*$%%'`
test "x$ac_confdir" = "x$ac_prog" && ac_confdir=.
diff --git a/tqtinterface/qt4/src/3rdparty/libmng/doc/libmng.txt b/tqtinterface/qt4/src/3rdparty/libmng/doc/libmng.txt
index 22ba338..ca6ee80 100644
--- a/tqtinterface/qt4/src/3rdparty/libmng/doc/libmng.txt
+++ b/tqtinterface/qt4/src/3rdparty/libmng/doc/libmng.txt
@@ -249,7 +249,7 @@ canvas and an optional separate alpha-channel canvas. The latter is
used only with the MNG_CANVAS_RGB8_A8 canvas-style.
If the getbkgdline() callback is not supplied the library will
-composite full or partially transtqparent pixels in the image against
+composite full or partially transparent pixels in the image against
a specified background color. See mng_set_bgcolor() for more details.
If a chosen canvas-style includes an alpha-channel, this callback
is very likely not needed.
@@ -674,13 +674,13 @@ actually need to be consecutive in memory.
> Alpha composition and application backgrounds
-All Network Graphics can be partially transtqparent. This requires
+All Network Graphics can be partially transparent. This requires
special processing if you need to display an image against some
background. Note that the MNG header (MHDR chunk) contains a
simplicity field indicating whether transparency information in
the file is critical or not. This only applies to embedded images,
which means the full image-frame of the MNG may still contain fully
-transtqparent pixels!
+transparent pixels!
Depending on your needs you can supply a single background color,
a background canvas or tell the library to return the alpha-channel
@@ -706,7 +706,7 @@ which matches your output requirements.
This is somewhat more complicated. You will need to set the
mng_getbkgdline() callback. This will be called whenever the library
-needs to compose a partially transtqparent line.
+needs to compose a partially transparent line.
This canvas must hold the background against which the image should
be composed. Its size must match exactly with the image dimensions
@@ -720,7 +720,7 @@ composing will still function properly.
> Composing within the application
If you have the option in your application to draw a (partially)
-transtqparent canvas to the output tqdevice, this option is preferred.
+transparent canvas to the output tqdevice, this option is preferred.
Select one of the canvas styles that do have an alpha-channel.
The library will now supply the appropriate alpha information,
diff --git a/tqtinterface/qt4/src/3rdparty/libmng/doc/man/libmng.3 b/tqtinterface/qt4/src/3rdparty/libmng/doc/man/libmng.3
index 782e424..7a6f544 100644
--- a/tqtinterface/qt4/src/3rdparty/libmng/doc/man/libmng.3
+++ b/tqtinterface/qt4/src/3rdparty/libmng/doc/man/libmng.3
@@ -263,7 +263,7 @@ canvas and an optional separate alpha-channel canvas. The latter is
used only with the MNG_CANVAS_RGB8_A8 canvas-style.
If the getbkgdline() callback is not supplied the library will
-composite full or partially transtqparent pixels in the image against
+composite full or partially transparent pixels in the image against
a specified background color. See mng_set_bgcolor() for more details.
If a chosen canvas-style includes an alpha-channel, this callback
is very likely not needed.
@@ -692,13 +692,13 @@ actually need to be consecutive in memory.
.SS Alpha composition and application backgrounds
-All Network Graphics can be partially transtqparent. This requires
+All Network Graphics can be partially transparent. This requires
special processing if you need to display an image against some
background. Note that the MNG header (MHDR chunk) contains a
simplicity field indicating whether transparency information in
the file is critical or not. This only applies to embedded images,
which means the full image-frame of the MNG may still contain fully
-transtqparent pixels!
+transparent pixels!
Depending on your needs you can supply a single background color,
a background canvas or tell the library to return the alpha-channel
@@ -724,7 +724,7 @@ which matches your output requirements.
This is somewhat more complicated. You will need to set the
mng_getbkgdline() callback. This will be called whenever the library
-needs to compose a partially transtqparent line.
+needs to compose a partially transparent line.
This canvas must hold the background against which the image should
be composed. Its size must match exactly with the image dimensions
@@ -738,7 +738,7 @@ composing will still function properly.
.SS Composing within the application
If you have the option in your application to draw a (partially)
-transtqparent canvas to the output tqdevice, this option is preferred.
+transparent canvas to the output tqdevice, this option is preferred.
Select one of the canvas styles that do have an alpha-channel.
The library will now supply the appropriate alpha information,
diff --git a/tqtinterface/qt4/src/3rdparty/libmng/libmng.h b/tqtinterface/qt4/src/3rdparty/libmng/libmng.h
index 035bb0e..9fd6160 100644
--- a/tqtinterface/qt4/src/3rdparty/libmng/libmng.h
+++ b/tqtinterface/qt4/src/3rdparty/libmng/libmng.h
@@ -2137,7 +2137,7 @@ MNG_EXT mng_retcode MNG_DECL mng_updatemngsimplicity (mng_handle hHandle,
#define MNG_WRONGCHUNK (mng_retcode)2050 /* accessing the wrong chunk */
#define MNG_INVALIDENTRYIX (mng_retcode)2051 /* accessing the wrong entry */
#define MNG_NOHEADER (mng_retcode)2052 /* must have had header first */
-#define MNG_NOCORRCHUNK (mng_retcode)2053 /* can't find tqparent chunk */
+#define MNG_NOCORRCHUNK (mng_retcode)2053 /* can't find parent chunk */
#define MNG_NOMHDR (mng_retcode)2054 /* no MNG header available */
#define MNG_IMAGETOOLARGE (mng_retcode)4097 /* input-image way too big */
diff --git a/tqtinterface/qt4/src/3rdparty/libmng/libmng_display.c b/tqtinterface/qt4/src/3rdparty/libmng/libmng_display.c
index 9cf26de..1b17d2a 100644
--- a/tqtinterface/qt4/src/3rdparty/libmng/libmng_display.c
+++ b/tqtinterface/qt4/src/3rdparty/libmng/libmng_display.c
@@ -574,7 +574,7 @@ mng_retcode clear_canvas (mng_datap pData)
set_display_routine (pData); /* determine display routine */
/* get a temporary row-buffer */
- /* it's transtqparent black by default!! */
+ /* it's transparent black by default!! */
MNG_ALLOC (pData, pData->pRGBArow, pData->iRowsize)
iY = pData->iDestt; /* this is where we start */
diff --git a/tqtinterface/qt4/src/3rdparty/libmng/libmng_trace.h b/tqtinterface/qt4/src/3rdparty/libmng/libmng_trace.h
index e8824da..2b493ec 100644
--- a/tqtinterface/qt4/src/3rdparty/libmng/libmng_trace.h
+++ b/tqtinterface/qt4/src/3rdparty/libmng/libmng_trace.h
@@ -127,7 +127,7 @@
/* ************************************************************************** */
-/* TODO: add a trace-tqmask so certain functions can be excluded */
+/* TODO: add a trace-mask so certain functions can be excluded */
mng_retcode mng_trace (mng_datap pData,
mng_uint32 iFunction,
diff --git a/tqtinterface/qt4/src/3rdparty/libmng/libmng_pixels.c b/tqtinterface/qt4/src/3rdparty/libmng/libmng_pixels.c
index 2803e3b..7379217 100644
--- a/tqtinterface/qt4/src/3rdparty/libmng/libmng_pixels.c
+++ b/tqtinterface/qt4/src/3rdparty/libmng/libmng_pixels.c
@@ -495,7 +495,7 @@ mng_retcode display_rgba8 (mng_datap pData)
iBGa16 = (mng_uint16)(iBGa16 << 8) | iBGa16;
if (iFGa16) /* any opacity at all ? */
- { /* fully opaque or background fully transtqparent ? */
+ { /* fully opaque or background fully transparent ? */
if ((iFGa16 == 0xFFFF) || (iBGa16 == 0))
{ /* plain copy it */
*pScanline = *pDataline;
@@ -562,7 +562,7 @@ mng_retcode display_rgba8 (mng_datap pData)
iBGa8 = *(pScanline+3);
if (iFGa8) /* any opacity at all ? */
- { /* fully opaque or background fully transtqparent ? */
+ { /* fully opaque or background fully transparent ? */
if ((iFGa8 == 0xFF) || (iBGa8 == 0))
{ /* then simply copy the values */
*pScanline = *pDataline;
@@ -682,7 +682,7 @@ mng_retcode display_argb8 (mng_datap pData)
iBGa16 = (mng_uint16)(iBGa16 << 8) | iBGa16;
if (iFGa16) /* any opacity at all ? */
- { /* fully opaque or background fully transtqparent ? */
+ { /* fully opaque or background fully transparent ? */
if ((iFGa16 == 0xFFFF) || (iBGa16 == 0))
{ /* plain copy it */
*pScanline = *(pDataline+6);
@@ -749,7 +749,7 @@ mng_retcode display_argb8 (mng_datap pData)
iBGa8 = *pScanline;
if (iFGa8) /* any opacity at all ? */
- { /* fully opaque or background fully transtqparent ? */
+ { /* fully opaque or background fully transparent ? */
if ((iFGa8 == 0xFF) || (iBGa8 == 0))
{ /* then simply copy the values */
*pScanline = *(pDataline+3);
@@ -876,7 +876,7 @@ mng_retcode display_rgb8_a8 (mng_datap pData)
iBGa16 = (mng_uint16)(iBGa16 << 8) | iBGa16;
if (iFGa16) /* any opacity at all ? */
- { /* fully opaque or background fully transtqparent ? */
+ { /* fully opaque or background fully transparent ? */
if ((iFGa16 == 0xFFFF) || (iBGa16 == 0))
{ /* plain copy it */
*pScanline = *pDataline;
@@ -944,7 +944,7 @@ mng_retcode display_rgb8_a8 (mng_datap pData)
iBGa8 = *pAlphaline;
if (iFGa8) /* any opacity at all ? */
- { /* fully opaque or background fully transtqparent ? */
+ { /* fully opaque or background fully transparent ? */
if ((iFGa8 == 0xFF) || (iBGa8 == 0))
{ /* then simply copy the values */
*pScanline = *pDataline;
@@ -1202,7 +1202,7 @@ mng_retcode display_bgra8 (mng_datap pData)
iBGa16 = (mng_uint16)(iBGa16 << 8) | iBGa16;
if (iFGa16) /* any opacity at all ? */
- { /* fully opaque or background fully transtqparent ? */
+ { /* fully opaque or background fully transparent ? */
if ((iFGa16 == 0xFFFF) || (iBGa16 == 0))
{ /* plain copy it */
*pScanline = *(pDataline+4);
@@ -1269,7 +1269,7 @@ mng_retcode display_bgra8 (mng_datap pData)
iBGa8 = *(pScanline+3);
if (iFGa8) /* any opacity at all ? */
- { /* fully opaque or background fully transtqparent ? */
+ { /* fully opaque or background fully transparent ? */
if ((iFGa8 == 0xFF) || (iBGa8 == 0))
{ /* then simply copy the values */
*pScanline = *(pDataline+2);
@@ -1408,7 +1408,7 @@ mng_retcode display_bgra8_pm (mng_datap pData)
for (iX = pData->iSourcel + pData->iCol; iX < pData->iSourcer; iX += pData->iColinc)
{ /* get alpha values */
if ((s = pDataline[6]) != 0) /* any opacity at all ? */
- { /* fully opaque or background fully transtqparent ? */
+ { /* fully opaque or background fully transparent ? */
if (s == 255)
{ /* plain copy it */
pScanline[0] = pDataline[4];
@@ -1541,7 +1541,7 @@ mng_retcode display_abgr8 (mng_datap pData)
iBGa16 = (mng_uint16)(iBGa16 << 8) | iBGa16;
if (iFGa16) /* any opacity at all ? */
- { /* fully opaque or background fully transtqparent ? */
+ { /* fully opaque or background fully transparent ? */
if ((iFGa16 == 0xFFFF) || (iBGa16 == 0))
{ /* plain copy it */
*pScanline = *(pDataline+6);
@@ -1608,7 +1608,7 @@ mng_retcode display_abgr8 (mng_datap pData)
iBGa8 = *pScanline;
if (iFGa8) /* any opacity at all ? */
- { /* fully opaque or background fully transtqparent ? */
+ { /* fully opaque or background fully transparent ? */
if ((iFGa8 == 0xFF) || (iBGa8 == 0))
{ /* then simply copy the values */
*pScanline = *(pDataline+3);
@@ -1945,7 +1945,7 @@ mng_retcode retrieve_g8 (mng_datap pData)
for (iX = 0; iX < pData->iRowsamples; iX++)
{
iG = *pWorkrow; /* get the gray-value */
- /* is it transtqparent ? */
+ /* is it transparent ? */
if ((mng_uint16)iG == pBuf->iTRNSgray)
{
*pRGBArow = 0x00; /* nuttin to display */
@@ -2024,7 +2024,7 @@ mng_retcode retrieve_g16 (mng_datap pData)
for (iX = 0; iX < pData->iRowsamples; iX++)
{
iG = mng_get_uint16 (pWorkrow); /* get the gray-value */
- /* is it transtqparent ? */
+ /* is it transparent ? */
if (iG == pBuf->iTRNSgray)
{ /* nuttin to display */
mng_put_uint16 (pRGBArow, 0x0000);
@@ -2091,7 +2091,7 @@ mng_retcode retrieve_rgb8 (mng_datap pData)
iR = *pWorkrow; /* get the rgb-values */
iG = *(pWorkrow+1);
iB = *(pWorkrow+2);
- /* is it transtqparent ? */
+ /* is it transparent ? */
if (((mng_uint16)iR == pBuf->iTRNSred ) &&
((mng_uint16)iG == pBuf->iTRNSgreen) &&
((mng_uint16)iB == pBuf->iTRNSblue ) )
@@ -2158,7 +2158,7 @@ mng_retcode retrieve_rgb16 (mng_datap pData)
iR = mng_get_uint16 (pWorkrow); /* get the rgb-values */
iG = mng_get_uint16 (pWorkrow+2);
iB = mng_get_uint16 (pWorkrow+4);
- /* is it transtqparent ? */
+ /* is it transparent ? */
if ((iR == pBuf->iTRNSred ) &&
(iG == pBuf->iTRNSgreen) &&
(iB == pBuf->iTRNSblue ) )
@@ -2419,7 +2419,7 @@ mng_retcode store_g1 (mng_datap pData)
for (iX = 0; iX < pData->iRowsamples; iX++)
{
- if (!iM) /* tqmask underflow ? */
+ if (!iM) /* mask underflow ? */
{
iB = *pWorkrow; /* get next input-byte */
pWorkrow++;
@@ -2468,7 +2468,7 @@ mng_retcode store_g2 (mng_datap pData)
for (iX = 0; iX < pData->iRowsamples; iX++)
{
- if (!iM) /* tqmask underflow ? */
+ if (!iM) /* mask underflow ? */
{
iB = *pWorkrow; /* get next input-byte */
pWorkrow++;
@@ -2517,7 +2517,7 @@ mng_retcode store_g4 (mng_datap pData)
for (iX = 0; iX < pData->iRowsamples; iX++)
{
- if (!iM) /* tqmask underflow ? */
+ if (!iM) /* mask underflow ? */
{
iB = *pWorkrow; /* get next input-byte */
pWorkrow++;
@@ -2693,7 +2693,7 @@ mng_retcode store_idx1 (mng_datap pData)
for (iX = 0; iX < pData->iRowsamples; iX++)
{
- if (!iM) /* tqmask underflow ? */
+ if (!iM) /* mask underflow ? */
{
iB = *pWorkrow; /* get next input-byte */
pWorkrow++;
@@ -2741,7 +2741,7 @@ mng_retcode store_idx2 (mng_datap pData)
for (iX = 0; iX < pData->iRowsamples; iX++)
{
- if (!iM) /* tqmask underflow ? */
+ if (!iM) /* mask underflow ? */
{
iB = *pWorkrow; /* get next input-byte */
pWorkrow++;
@@ -2788,7 +2788,7 @@ mng_retcode store_idx4 (mng_datap pData)
for (iX = 0; iX < pData->iRowsamples; iX++)
{
- if (!iM) /* tqmask underflow ? */
+ if (!iM) /* mask underflow ? */
{
iB = *pWorkrow; /* get next input-byte */
pWorkrow++;
@@ -3180,7 +3180,7 @@ mng_retcode store_jpeg_g8_a1 (mng_datap pData)
for (iX = 0; iX < pData->iRowsamples; iX++)
{
- if (!iM) /* tqmask underflow ? */
+ if (!iM) /* mask underflow ? */
{
iB = *pWorkrow; /* get next input-byte */
pWorkrow++;
@@ -3190,7 +3190,7 @@ mng_retcode store_jpeg_g8_a1 (mng_datap pData)
if (iB & iM) /* is it opaque ? */
*pOutrow = 0xFF; /* opaque */
else
- *pOutrow = 0x00; /* transtqparent */
+ *pOutrow = 0x00; /* transparent */
pOutrow += 2; /* next pixel */
iM >>= 1;
@@ -3228,7 +3228,7 @@ mng_retcode store_jpeg_g8_a2 (mng_datap pData)
for (iX = 0; iX < pData->iRowsamples; iX++)
{
- if (!iM) /* tqmask underflow ? */
+ if (!iM) /* mask underflow ? */
{
iB = *pWorkrow; /* get next input-byte */
pWorkrow++;
@@ -3282,7 +3282,7 @@ mng_retcode store_jpeg_g8_a4 (mng_datap pData)
for (iX = 0; iX < pData->iRowsamples; iX++)
{
- if (!iM) /* tqmask underflow ? */
+ if (!iM) /* mask underflow ? */
{
iB = *pWorkrow; /* get next input-byte */
pWorkrow++;
@@ -3394,7 +3394,7 @@ mng_retcode store_jpeg_rgb8_a1 (mng_datap pData)
for (iX = 0; iX < pData->iRowsamples; iX++)
{
- if (!iM) /* tqmask underflow ? */
+ if (!iM) /* mask underflow ? */
{
iB = *pWorkrow; /* get next input-byte */
pWorkrow++;
@@ -3404,7 +3404,7 @@ mng_retcode store_jpeg_rgb8_a1 (mng_datap pData)
if (iB & iM) /* is it opaque ? */
*pOutrow = 0xFF; /* opaque */
else
- *pOutrow = 0x00; /* transtqparent */
+ *pOutrow = 0x00; /* transparent */
pOutrow += 4; /* next pixel */
iM >>= 1;
@@ -3442,7 +3442,7 @@ mng_retcode store_jpeg_rgb8_a2 (mng_datap pData)
for (iX = 0; iX < pData->iRowsamples; iX++)
{
- if (!iM) /* tqmask underflow ? */
+ if (!iM) /* mask underflow ? */
{
iB = *pWorkrow; /* get next input-byte */
pWorkrow++;
@@ -3496,7 +3496,7 @@ mng_retcode store_jpeg_rgb8_a4 (mng_datap pData)
for (iX = 0; iX < pData->iRowsamples; iX++)
{
- if (!iM) /* tqmask underflow ? */
+ if (!iM) /* mask underflow ? */
{
iB = *pWorkrow; /* get next input-byte */
pWorkrow++;
@@ -3608,7 +3608,7 @@ mng_retcode store_jpeg_g12_a1 (mng_datap pData)
for (iX = 0; iX < pData->iRowsamples; iX++)
{
- if (!iM) /* tqmask underflow ? */
+ if (!iM) /* mask underflow ? */
{
iB = *pWorkrow; /* get next input-byte */
pWorkrow++;
@@ -3618,7 +3618,7 @@ mng_retcode store_jpeg_g12_a1 (mng_datap pData)
if (iB & iM) /* opaque ? */
mng_put_uint16 (pOutrow, 0xFFFF);/* opaque */
else
- mng_put_uint16 (pOutrow, 0x0000);/* transtqparent */
+ mng_put_uint16 (pOutrow, 0x0000);/* transparent */
pOutrow += 4; /* next pixel */
iM >>= 1;
@@ -3656,7 +3656,7 @@ mng_retcode store_jpeg_g12_a2 (mng_datap pData)
for (iX = 0; iX < pData->iRowsamples; iX++)
{
- if (!iM) /* tqmask underflow ? */
+ if (!iM) /* mask underflow ? */
{
iB = *pWorkrow; /* get next input-byte */
pWorkrow++;
@@ -3710,7 +3710,7 @@ mng_retcode store_jpeg_g12_a4 (mng_datap pData)
for (iX = 0; iX < pData->iRowsamples; iX++)
{
- if (!iM) /* tqmask underflow ? */
+ if (!iM) /* mask underflow ? */
{
iB = *pWorkrow; /* get next input-byte */
pWorkrow++;
@@ -3840,7 +3840,7 @@ mng_retcode delta_g1 (mng_datap pData)
{
for (iX = 0; iX < pData->iRowsamples; iX++)
{
- if (!iM) /* tqmask underflow ? */
+ if (!iM) /* mask underflow ? */
{
iB = *pWorkrow; /* get next input-byte */
pWorkrow++;
@@ -3860,7 +3860,7 @@ mng_retcode delta_g1 (mng_datap pData)
{ /* pixel add ! */
for (iX = 0; iX < pData->iRowsamples; iX++)
{
- if (!iM) /* tqmask underflow ? */
+ if (!iM) /* mask underflow ? */
{
iB = *pWorkrow; /* get next input-byte */
pWorkrow++;
@@ -3911,7 +3911,7 @@ mng_retcode delta_g2 (mng_datap pData)
{
for (iX = 0; iX < pData->iRowsamples; iX++)
{
- if (!iM) /* tqmask underflow ? */
+ if (!iM) /* mask underflow ? */
{
iB = *pWorkrow; /* get next input-byte */
pWorkrow++;
@@ -3936,7 +3936,7 @@ mng_retcode delta_g2 (mng_datap pData)
{ /* pixel add ! */
for (iX = 0; iX < pData->iRowsamples; iX++)
{
- if (!iM) /* tqmask underflow ? */
+ if (!iM) /* mask underflow ? */
{
iB = *pWorkrow; /* get next input-byte */
pWorkrow++;
@@ -3995,7 +3995,7 @@ mng_retcode delta_g4 (mng_datap pData)
{
for (iX = 0; iX < pData->iRowsamples; iX++)
{
- if (!iM) /* tqmask underflow ? */
+ if (!iM) /* mask underflow ? */
{
iB = *pWorkrow; /* get next input-byte */
pWorkrow++;
@@ -4018,7 +4018,7 @@ mng_retcode delta_g4 (mng_datap pData)
{ /* pixel add ! */
for (iX = 0; iX < pData->iRowsamples; iX++)
{
- if (!iM) /* tqmask underflow ? */
+ if (!iM) /* mask underflow ? */
{
iB = *pWorkrow; /* get next input-byte */
pWorkrow++;
@@ -4276,7 +4276,7 @@ mng_retcode delta_idx1 (mng_datap pData)
{
for (iX = 0; iX < pData->iRowsamples; iX++)
{
- if (!iM) /* tqmask underflow ? */
+ if (!iM) /* mask underflow ? */
{
iB = *pWorkrow; /* get next input-byte */
pWorkrow++;
@@ -4296,7 +4296,7 @@ mng_retcode delta_idx1 (mng_datap pData)
{ /* pixel add ! */
for (iX = 0; iX < pData->iRowsamples; iX++)
{
- if (!iM) /* tqmask underflow ? */
+ if (!iM) /* mask underflow ? */
{
iB = *pWorkrow; /* get next input-byte */
pWorkrow++;
@@ -4347,7 +4347,7 @@ mng_retcode delta_idx2 (mng_datap pData)
{
for (iX = 0; iX < pData->iRowsamples; iX++)
{
- if (!iM) /* tqmask underflow ? */
+ if (!iM) /* mask underflow ? */
{
iB = *pWorkrow; /* get next input-byte */
pWorkrow++;
@@ -4366,7 +4366,7 @@ mng_retcode delta_idx2 (mng_datap pData)
{ /* pixel add ! */
for (iX = 0; iX < pData->iRowsamples; iX++)
{
- if (!iM) /* tqmask underflow ? */
+ if (!iM) /* mask underflow ? */
{
iB = *pWorkrow; /* get next input-byte */
pWorkrow++;
@@ -4418,7 +4418,7 @@ mng_retcode delta_idx4 (mng_datap pData)
{
for (iX = 0; iX < pData->iRowsamples; iX++)
{
- if (!iM) /* tqmask underflow ? */
+ if (!iM) /* mask underflow ? */
{
iB = *pWorkrow; /* get next input-byte */
pWorkrow++;
@@ -4437,7 +4437,7 @@ mng_retcode delta_idx4 (mng_datap pData)
{ /* pixel add ! */
for (iX = 0; iX < pData->iRowsamples; iX++)
{
- if (!iM) /* tqmask underflow ? */
+ if (!iM) /* mask underflow ? */
{
iB = *pWorkrow; /* get next input-byte */
pWorkrow++;
@@ -5629,11 +5629,11 @@ mng_retcode process_g1 (mng_datap pData)
if (pBuf->bHasTRNS) /* tRNS encountered ? */
{
- if (pBuf->iTRNSgray) /* white transtqparent ? */
+ if (pBuf->iTRNSgray) /* white transparent ? */
{
for (iX = 0; iX < pData->iRowsamples; iX++)
{
- if (!iM) /* tqmask underflow ? */
+ if (!iM) /* mask underflow ? */
{
iB = *pWorkrow; /* get next input-byte */
pWorkrow++;
@@ -5641,7 +5641,7 @@ mng_retcode process_g1 (mng_datap pData)
}
if (iB & iM) /* is it white ? */
- /* transtqparent ! */
+ /* transparent ! */
mng_put_uint32 (pRGBArow, 0x00000000);
else /* opaque black */
mng_put_uint32 (pRGBArow, 0x000000FF);
@@ -5650,11 +5650,11 @@ mng_retcode process_g1 (mng_datap pData)
iM >>= 1;
}
}
- else /* black transtqparent */
+ else /* black transparent */
{
for (iX = 0; iX < pData->iRowsamples; iX++)
{
- if (!iM) /* tqmask underflow ? */
+ if (!iM) /* mask underflow ? */
{
iB = *pWorkrow; /* get next input-byte */
pWorkrow++;
@@ -5664,7 +5664,7 @@ mng_retcode process_g1 (mng_datap pData)
if (iB & iM) /* is it white ? */
/* opaque white */
mng_put_uint32 (pRGBArow, 0xFFFFFFFF);
- else /* transtqparent */
+ else /* transparent */
mng_put_uint32 (pRGBArow, 0x00000000);
pRGBArow += 4; /* next pixel */
@@ -5678,7 +5678,7 @@ mng_retcode process_g1 (mng_datap pData)
{
for (iX = 0; iX < pData->iRowsamples; iX++)
{
- if (!iM) /* tqmask underflow ? */
+ if (!iM) /* mask underflow ? */
{
iB = *pWorkrow; /* get next input-byte */
pWorkrow++;
@@ -5735,7 +5735,7 @@ mng_retcode process_g2 (mng_datap pData)
{
for (iX = 0; iX < pData->iRowsamples; iX++)
{
- if (!iM) /* tqmask underflow ? */
+ if (!iM) /* mask underflow ? */
{
iB = *pWorkrow; /* get next input-byte */
pWorkrow++;
@@ -5745,7 +5745,7 @@ mng_retcode process_g2 (mng_datap pData)
/* determine gray level */
iQ = (mng_uint8)((iB & iM) >> iS);
- if (iQ == pBuf->iTRNSgray) /* transtqparent ? */
+ if (iQ == pBuf->iTRNSgray) /* transparent ? */
mng_put_uint32 (pRGBArow, 0x00000000);
else
{
@@ -5769,7 +5769,7 @@ mng_retcode process_g2 (mng_datap pData)
{
for (iX = 0; iX < pData->iRowsamples; iX++)
{
- if (!iM) /* tqmask underflow ? */
+ if (!iM) /* mask underflow ? */
{
iB = *pWorkrow; /* get next input-byte */
pWorkrow++;
@@ -5830,7 +5830,7 @@ mng_retcode process_g4 (mng_datap pData)
{
for (iX = 0; iX < pData->iRowsamples; iX++)
{
- if (!iM) /* tqmask underflow ? */
+ if (!iM) /* mask underflow ? */
{
iB = *pWorkrow; /* get next input-byte */
pWorkrow++;
@@ -5840,7 +5840,7 @@ mng_retcode process_g4 (mng_datap pData)
/* get the gray level */
iQ = (mng_uint8)((iB & iM) >> iS);
- if (iQ == pBuf->iTRNSgray) /* transtqparent ? */
+ if (iQ == pBuf->iTRNSgray) /* transparent ? */
{
*pRGBArow = 0; /* put in intermediate row */
*(pRGBArow+1) = 0;
@@ -5868,7 +5868,7 @@ mng_retcode process_g4 (mng_datap pData)
{
for (iX = 0; iX < pData->iRowsamples; iX++)
{
- if (!iM) /* tqmask underflow ? */
+ if (!iM) /* mask underflow ? */
{
iB = *pWorkrow; /* get next input-byte */
pWorkrow++;
@@ -5925,7 +5925,7 @@ mng_retcode process_g8 (mng_datap pData)
{
iB = *pWorkrow; /* get next input-byte */
- if (iB == pBuf->iTRNSgray) /* transtqparent ? */
+ if (iB == pBuf->iTRNSgray) /* transparent ? */
{
*pRGBArow = 0; /* put in intermediate row */
*(pRGBArow+1) = 0;
@@ -5997,7 +5997,7 @@ mng_retcode process_g16 (mng_datap pData)
{
iW = mng_get_uint16 (pWorkrow); /* get input */
- if (iW == pBuf->iTRNSgray) /* transtqparent ? */
+ if (iW == pBuf->iTRNSgray) /* transparent ? */
{ /* put in intermediate row */
mng_put_uint16 (pRGBArow, 0);
mng_put_uint16 (pRGBArow+2, 0);
@@ -6070,11 +6070,11 @@ mng_retcode process_rgb8 (mng_datap pData)
iR = *pWorkrow; /* get the RGB values */
iG = *(pWorkrow+1);
iB = *(pWorkrow+2);
- /* transtqparent ? */
+ /* transparent ? */
if ((iR == pBuf->iTRNSred) && (iG == pBuf->iTRNSgreen) &&
(iB == pBuf->iTRNSblue))
{
- *pRGBArow = 0; /* this pixel is transtqparent ! */
+ *pRGBArow = 0; /* this pixel is transparent ! */
*(pRGBArow+1) = 0;
*(pRGBArow+2) = 0;
*(pRGBArow+3) = 0;
@@ -6084,7 +6084,7 @@ mng_retcode process_rgb8 (mng_datap pData)
*pRGBArow = iR; /* copy the RGB values */
*(pRGBArow+1) = iG;
*(pRGBArow+2) = iB;
*(pRGBArow+3) = 0xFF; /* this one isn't transtqparent */
}
pWorkrow += 3; /* next pixel */
@@ -6143,10 +6143,10 @@ mng_retcode process_rgb16 (mng_datap pData)
iR = mng_get_uint16 (pWorkrow); /* get the RGB values */
iG = mng_get_uint16 (pWorkrow+2);
iB = mng_get_uint16 (pWorkrow+4);
- /* transtqparent ? */
+ /* transparent ? */
if ((iR == pBuf->iTRNSred) && (iG == pBuf->iTRNSgreen) &&
(iB == pBuf->iTRNSblue))
- { /* transtqparent then */
+ { /* transparent then */
mng_put_uint16 (pRGBArow, 0);
mng_put_uint16 (pRGBArow+2, 0);
mng_put_uint16 (pRGBArow+4, 0);
@@ -6219,7 +6219,7 @@ mng_retcode process_idx1 (mng_datap pData)
{
for (iX = 0; iX < pData->iRowsamples; iX++)
{
- if (!iM) /* tqmask underflow ? */
+ if (!iM) /* mask underflow ? */
{
iB = *pWorkrow; /* get next input-byte */
pWorkrow++;
@@ -6254,7 +6254,7 @@ mng_retcode process_idx1 (mng_datap pData)
{
for (iX = 0; iX < pData->iRowsamples; iX++)
{
- if (!iM) /* tqmask underflow ? */
+ if (!iM) /* mask underflow ? */
{
iB = *pWorkrow; /* get next input-byte */
pWorkrow++;
@@ -6319,7 +6319,7 @@ mng_retcode process_idx2 (mng_datap pData)
{
for (iX = 0; iX < pData->iRowsamples; iX++)
{
- if (!iM) /* tqmask underflow ? */
+ if (!iM) /* mask underflow ? */
{
iB = *pWorkrow; /* get next input-byte */
pWorkrow++;
@@ -6354,7 +6354,7 @@ mng_retcode process_idx2 (mng_datap pData)
{
for (iX = 0; iX < pData->iRowsamples; iX++)
{
- if (!iM) /* tqmask underflow ? */
+ if (!iM) /* mask underflow ? */
{
iB = *pWorkrow; /* get next input-byte */
pWorkrow++;
@@ -6419,7 +6419,7 @@ mng_retcode process_idx4 (mng_datap pData)
{
for (iX = 0; iX < pData->iRowsamples; iX++)
{
- if (!iM) /* tqmask underflow ? */
+ if (!iM) /* mask underflow ? */
{
iB = pWorkrow [0]; /* get next input-byte */
pWorkrow++;
@@ -6454,7 +6454,7 @@ mng_retcode process_idx4 (mng_datap pData)
{
for (iX = 0; iX < pData->iRowsamples; iX++)
{
- if (!iM) /* tqmask underflow ? */
+ if (!iM) /* mask underflow ? */
{
iB = pWorkrow [0]; /* get next input-byte */
pWorkrow++;
@@ -6084,7 +6084,7 @@ mng_retcode process_rgb8 (mng_datap pData)
*(pRGBArow+1) = iG;
*(pRGBArow+2) = iB;
- *(pRGBArow+3) = 0xFF; /* this one isn't transtqparent */
+ *(pRGBArow+3) = 0xFF; /* this one isn't transparent */
}
pWorkrow += 3; /* next pixel */